@@ -1,4 +1,3 @@
-use solana_measure::measure::Measure;
 /// Main entry for the PostgreSQL plugin
 use {
     crate::{
@@ -14,6 +13,7 @@ use {
         AccountsDbPlugin, AccountsDbPluginError, ReplicaAccountInfoVersions,
         ReplicaBlockInfoVersions, ReplicaTransactionInfoVersions, Result, SlotStatus,
     },
+    solana_measure::measure::Measure,
     solana_metrics::*,
     std::{fs::File, io::Read},
     thiserror::Error,
@@ -43,6 +43,10 @@ pub struct AccountsDbPluginPostgresConfig {
     pub panic_on_db_errors: Option<bool>,
     /// Indicates if to store historical data for accounts
     pub store_account_historical_data: Option<bool>,
+    pub use_ssl: Option<bool>,
+    pub server_ca: Option<String>,
+    pub client_cert: Option<String>,
+    pub client_key: Option<String>,
 }
 
 #[derive(Error, Debug)]
